library(stringi)
library(readxl)
library(lme4)
library(dplyr)

# http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0173793

# Corrected two "Pith" to "Pini"
dataDF <- read_xlsx("202711_journal.pone.0173793.s003.xlsx")
dataDF$Study <- as.integer(unlist(stri_extract_all_regex(dataDF$Study, "[0-9]+")))
dataDF$Participant <- as.factor(dataDF$Participant)
dataDF$Species <- as.factor(dataDF$Species)
dataDF$Sex <- as.factor(dataDF$Sex)
dataDF$`Condition in study` <- as.factor(dataDF$`Condition in study`)
# TB: True Belief
# FB/FB2: False Belief
# I: Ignorance

# Response (1 = Selected box with object, 0 = Selected an empty box)


## Study 1

dataDF %>% filter(Study == 1) %>% select(Participant, 
                                         Species, 
                                         Age = `Age in years`, 
                                         Sex,
                                         Condition = `Condition in study`,
                                         Trial = `Trial number`,
                                         Response) %>%
  glmer(Response ~ 1 + (1 | Participant), family = "binomial", data = .) %>%
  summary()
  


dataDF %>% filter(Study == 1) %>% select(Participant, 
                                         Species, 
                                         Age = `Age in years`, 
                                         Sex,
                                         Condition = `Condition in study`,
                                         Trial = `Trial number`,
                                         Response) %>%
  glmer(Response ~ Condition + Sex + Age + Species + (1 | Participant), family = "binomial", data = .) %>% 
  summary()


# Study 2

dataDF %>% filter(Study == 2) %>% select(Participant, 
                                         Species, 
                                         Age = `Age in years`, 
                                         Sex,
                                         Condition = `Condition in study`,
                                         Trial = `Trial number`,
                                         Response) %>%
  glmer(Response ~ 1 + (1 | Participant), family = "binomial", data = .) %>%
  summary()



dataDF %>% filter(Study == 2) %>% select(Participant, 
                                         Species, 
                                         Age = `Age in years`, 
                                         Sex,
                                         Condition = `Condition in study`,
                                         Trial = `Trial number`,
                                         Response) %>%
  glmer(Response ~ Condition + Sex + Age + Species + (1 | Participant), family = "binomial", data = .) %>% 
  summary()
